@@ -329,11 +329,14 @@ dsn_config_new (void)
 	GtkWidget *label;
 
 	priv = g_new0 (DsnConfigPrivate, 1);
-	dsn = gnome_db_new_vbox_widget (FALSE, 0);
+	dsn = gnome_db_new_vbox_widget (FALSE, 6);
+        gtk_container_set_border_width (GTK_CONTAINER (dsn), 6);
 	g_object_set_data_full (G_OBJECT (dsn), DSN_CONFIG_DATA, priv,
 				(GDestroyNotify) free_private_data);
 
 	table = gnome_db_new_table_widget (2, 2, FALSE);
+        gtk_table_set_row_spacings (GTK_TABLE (table), 6);
+        gtk_table_set_col_spacings (GTK_TABLE (table), 6);
 	gtk_box_pack_start (GTK_BOX (dsn), table, TRUE, TRUE, 0);
 
 	/* create the data source list */
@@ -344,51 +347,55 @@ dsn_config_new (void)
 	gtk_table_attach (GTK_TABLE (table), priv->dsn_list, 0, 1, 0, 1,
 			  GTK_FILL | GTK_SHRINK | GTK_EXPAND,
 			  GTK_FILL | GTK_SHRINK | GTK_EXPAND,
-			  2, 2);
+			  0, 0);
 	show_data_sources (priv);
 
 	/* add buttons */
 	box = gtk_vbutton_box_new ();
-	gtk_box_set_spacing (GTK_BOX (box), 4);
+	gtk_box_set_spacing (GTK_BOX (box), 6);
 	gtk_button_box_set_layout (GTK_BUTTON_BOX (box), GTK_BUTTONBOX_START);
 	gtk_widget_show (box);
 	gtk_table_attach (GTK_TABLE (table), box, 1, 2, 0, 1,
-			  GTK_FILL, GTK_FILL, 2, 2);
+			  GTK_FILL, GTK_FILL,
+                          0, 0);
 
 	button = gnome_db_new_button_widget_from_stock (GTK_STOCK_NEW);
 	g_signal_connect (G_OBJECT (button), "clicked",
 			  G_CALLBACK (new_dsn_cb), priv);
-	gtk_box_pack_start (GTK_BOX (box), button, FALSE, FALSE, 2);
+	gtk_box_pack_start (GTK_BOX (box), button, FALSE, FALSE, 0);
 
 	button = gnome_db_new_button_widget_from_stock (GTK_STOCK_PROPERTIES);
 	g_signal_connect (G_OBJECT (button), "clicked",
 			  G_CALLBACK (edit_dsn_cb), priv);
-	gtk_box_pack_start (GTK_BOX (box), button, FALSE, FALSE, 2);
+	gtk_box_pack_start (GTK_BOX (box), button, FALSE, FALSE, 0);
 
 	button = gnome_db_new_button_widget (_("Test"));
 	g_signal_connect (G_OBJECT (button), "clicked",
 			  G_CALLBACK (test_dsn_cb), priv);
-	gtk_box_pack_start (GTK_BOX (box), button, FALSE, FALSE, 2);
+	gtk_box_pack_start (GTK_BOX (box), button, FALSE, FALSE, 0);
 
 	button = gnome_db_new_button_widget_from_stock (GTK_STOCK_DELETE);
 	g_signal_connect (G_OBJECT (button), "clicked",
 			  G_CALLBACK (remove_dsn_cb), priv);
-	gtk_box_pack_start (GTK_BOX (box), button, FALSE, FALSE, 2);
+	gtk_box_pack_start (GTK_BOX (box), button, FALSE, FALSE, 0);
 
 	button = gnome_db_new_button_widget_from_stock (GTK_STOCK_REFRESH);
 	g_signal_connect (G_OBJECT (button), "clicked",
 			  G_CALLBACK (refresh_list_cb), priv);
-	gtk_box_pack_start (GTK_BOX (box), button, FALSE, FALSE, 2);
+	gtk_box_pack_start (GTK_BOX (box), button, FALSE, FALSE, 0);
 
 	/* add tip */
-	box = gnome_db_new_hbox_widget (FALSE, 3);
+	box = gnome_db_new_hbox_widget (FALSE, 6);
+        gtk_container_set_border_width (GTK_CONTAINER (box), 6);
 	gtk_table_attach (GTK_TABLE (table), box, 0, 2, 1, 2,
 			  GTK_FILL | GTK_EXPAND | GTK_SHRINK,
-			  GTK_FILL | GTK_EXPAND | GTK_SHRINK, 5, 5);
+			  GTK_FILL | GTK_EXPAND | GTK_SHRINK,
+                          0, 0);
 
 	button = gtk_image_new_from_stock (GTK_STOCK_DIALOG_INFO, GTK_ICON_SIZE_DIALOG);
+        gtk_misc_set_alignment (GTK_MISC (button), 0.5, 0.0);
 	gtk_widget_show (button);
-	gtk_box_pack_start (GTK_BOX (box), button, FALSE, FALSE, 3);
+	gtk_box_pack_start (GTK_BOX (box), button, FALSE, FALSE, 0);
 
 	label = gnome_db_new_label_widget (
 		_("Data sources are the means by which database "
@@ -399,7 +406,9 @@ dsn_config_new (void)
 		  "you identify the connections in the applications "
 		  "that make use of GNOME-DB for database access."));
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-	gtk_box_pack_start (GTK_BOX (box), label, TRUE, TRUE, 3);
+        gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);
+        gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
+	gtk_box_pack_start (GTK_BOX (box), label, TRUE, TRUE, 0);
 	
 	return dsn;
 }
