@@ -45,6 +45,8 @@ create_dialog (gpointer user_data)
 					      GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 					      NULL);
 	gtk_widget_set_usize (dialog, 450, 500);
+        gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
+        gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
 	gnome_window_icon_set_from_file (GTK_WINDOW (dialog),
 					 LIBGNOMEDB_ICONSDIR "/gnome-db.png");
@@ -52,6 +54,8 @@ create_dialog (gpointer user_data)
 			  G_CALLBACK (dialog_response_cb), NULL);
 
 	capplet = database_capplet_new ();
+        gtk_container_set_border_width (GTK_CONTAINER (capplet), 6);
+        gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 6);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), capplet, TRUE, TRUE, 0);
 
 	/* run the dialog */
