@@ -73,6 +73,13 @@ data_model_info_get_type (void)
 	return type;
 }
 
+static void
+column_clicked_cb (GtkTreeViewColumn *column, gpointer user_data)
+{
+	//gtk_tree_view_set_search_column (GTK_TREE_VIEW (user_data),
+	//				 gtk_tree_view_column_get_sort_column_id (column));
+}
+
 static gint
 sort_values (GtkTreeModel *model, GtkTreeIter *itera, GtkTreeIter *iterb, gpointer user_data)
 {
@@ -138,7 +145,7 @@ default_value_set_func (GtkTreeViewColumn *tree_column,
 			gpointer user_data)
 {
 	DataModelInfo *info = NULL;
-	const GdaValue *value;
+	GdaValue *value;
 	gchar *txt;
 	gchar *str;
 
@@ -146,13 +153,13 @@ default_value_set_func (GtkTreeViewColumn *tree_column,
 	if (!info)
 		return;
 
-	value = gda_data_model_get_value_at (info->model,
+	value = (const GdaValue *) gda_data_model_get_value_at (info->model,
 					     GPOINTER_TO_INT (user_data),
 					     info->row);
 	if (!value)
 		return;
 
-	txt = gda_value_stringify ((GdaValue *) value);
+	txt = gda_value_stringify (value);
 	if (gda_value_isa (value, GDA_VALUE_TYPE_BIGINT)
 	    || gda_value_isa (value, GDA_VALUE_TYPE_DOUBLE)
 	    || gda_value_isa (value, GDA_VALUE_TYPE_INTEGER)
@@ -163,11 +170,12 @@ default_value_set_func (GtkTreeViewColumn *tree_column,
 		/* FIXME: get color for numbers from configuration */
 		str = g_strdup_printf ("<span foreground=\"#0000FF\">%s</span>", txt);
 		g_object_set (G_OBJECT (cell), "markup", str,
-			      "xalign", 1.0, NULL);
+			      "xalign", 1.0,
+			      "yalign", 0.0, NULL);
 		g_free (str);
 	}
 	else
-		g_object_set (G_OBJECT (cell), "text", txt, NULL);
+		g_object_set (G_OBJECT (cell), "text", txt, "yalign", 0.0, NULL);
 
 	g_free (txt);
 }
@@ -194,6 +202,7 @@ toggle_value_set_func (GtkTreeViewColumn *tree_column,
 
 	gtk_cell_renderer_toggle_set_active (GTK_CELL_RENDERER_TOGGLE (cell),
 					     gda_value_get_boolean ((GdaValue *) value));
+	g_object_set (G_OBJECT (cell), "xalign", 0.0, "yalign", 0.0, NULL);
 }
 
 static gchar *
@@ -229,6 +238,84 @@ add_tree_model_row (GtkTreeStore *tree_model, GdaDataModel *model,
 	}
 }
 
+static void
+model_row_inserted_cb (GdaDataModel *model, gint row, gpointer user_data)
+{
+	GtkTreeView *tree_view = user_data;
+
+	add_tree_model_row (gtk_tree_view_get_model (tree_view), model, NULL, row);
+}
+
+static void
+model_row_updated_cb (GdaDataModel *model, gint row, gpointer user_data)
+{
+	GtkTreeIter iter;
+	GtkTreePath *path;
+	GtkTreeView *tree_view = user_data;
+
+	gtk_tree_model_iter_nth_child (gtk_tree_view_get_model (tree_view), &iter, NULL, row);
+	path = gtk_tree_path_new ();
+	gtk_tree_path_append_index (path, row);
+	gtk_tree_model_row_changed (gtk_tree_view_get_model (tree_view), path, &iter);
+
+	gtk_tree_path_free (path);
+}
+
+static void
+model_row_removed_cb (GdaDataModel *model, gint row, gpointer user_data)
+{
+	GtkTreePath *path;
+	GtkTreeView *tree_view = user_data;
+
+	path = gtk_tree_path_new ();
+	gtk_tree_path_append_index (path, row);
+	gtk_tree_model_row_deleted (gtk_tree_view_get_model (tree_view), path);
+
+	gtk_tree_path_free (path);
+}
+
+static gboolean
+tree_view_equal_func (GtkTreeModel *model,
+		      gint column,
+		      const gchar *key,
+		      GtkTreeIter *iter,
+		      gpointer user_data)
+{
+	DataModelInfo *info = NULL;
+	const GdaValue *value;
+	gint key_len;
+	gboolean retval = TRUE;
+	gchar *normalized_string, *normalized_key, *tmp, *case_ns, *case_nk;
+
+	gtk_tree_model_get (model, iter, 0, &info, -1);
+	if (!info)
+		return TRUE;
+
+	value = gda_data_model_get_value_at (info->model, column, info->row);
+	if (!value)
+		return TRUE;
+
+	/* normalize strings for UTF8 */
+	tmp = gda_value_stringify (value);
+	normalized_string = g_utf8_normalize (tmp, -1, G_NORMALIZE_ALL);
+	normalized_key = g_utf8_normalize (key, -1, G_NORMALIZE_ALL);
+	case_ns = g_utf8_casefold (normalized_string, -1);
+	case_nk = g_utf8_casefold (normalized_key, -1);
+
+	g_free (tmp);
+
+	key_len = strlen (case_nk);
+	if (!strncmp (case_nk, case_ns, key_len))
+		retval = FALSE;
+
+	g_free (normalized_key);
+	g_free (normalized_string);
+	g_free (case_nk);
+	g_free (case_ns);
+                                                                                           
+	return retval;
+}
+
 /**
  * gnome_db_model_to_gtk_tree_view
  * @model: a #GdaDataModel object.
@@ -259,6 +346,13 @@ gnome_db_model_to_gtk_tree_view (GdaDataModel *model)
 	g_object_unref (G_OBJECT (tree_model));
 
 	col_count = gda_data_model_get_n_columns (model);
+	if (col_count > 0) {
+		//gtk_tree_view_set_search_equal_func (GTK_TREE_VIEW (tree_view),
+		//				     (GtkTreeViewSearchEqualFunc) tree_view_equal_func,
+		//				     tree_view, NULL);
+		//gtk_tree_view_set_search_column (GTK_TREE_VIEW (tree_view), 0);
+	}
+
 	for (i = 0; i < col_count; i++) {
 		GtkTreeViewColumn *column;
 		GtkCellRenderer *renderer;
@@ -274,7 +368,7 @@ gnome_db_model_to_gtk_tree_view (GdaDataModel *model)
 		}
 		attrs = gda_data_model_describe_column (model, i);
 		if (attrs && attrs->gda_type == GDA_VALUE_TYPE_BOOLEAN) {
-			renderer = gtk_cell_renderer_toggle_new ();
+						renderer = gtk_cell_renderer_toggle_new ();
 			gtk_tree_view_insert_column_with_data_func (
 				GTK_TREE_VIEW (tree_view),
 				i,
@@ -303,6 +397,8 @@ gnome_db_model_to_gtk_tree_view (GdaDataModel *model)
 		gtk_tree_view_column_set_sort_column_id (column, i);
 		gtk_tree_view_column_set_resizable (column, TRUE);
 		gtk_tree_view_column_set_clickable (column, TRUE);
+		g_signal_connect (G_OBJECT (column), "clicked",
+				  G_CALLBACK (column_clicked_cb), tree_view);
 
 		gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (tree_model),
 						 i, sort_values,
@@ -314,5 +410,10 @@ gnome_db_model_to_gtk_tree_view (GdaDataModel *model)
 
 	gtk_tree_view_set_headers_clickable (GTK_TREE_VIEW (tree_view), TRUE);
 
+	/* connect to data model's signals */
+	g_signal_connect (G_OBJECT (model), "row_inserted", G_CALLBACK (model_row_inserted_cb), tree_view);
+	g_signal_connect (G_OBJECT (model), "row_updated", G_CALLBACK (model_row_updated_cb), tree_view);
+	g_signal_connect (G_OBJECT (model), "row_removed", G_CALLBACK (model_row_removed_cb), tree_view);
+
 	return tree_view;
 }
