@@ -21,7 +21,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include <string.h>
 #include <libintl.h>
 #include <glib-object.h>
 #include <gtk/gtkbutton.h>
@@ -702,12 +702,6 @@ gnome_db_text_set_text (GtkTextView *text, const gchar *contents, gint len)
 	gtk_text_buffer_set_text (gtk_text_view_get_buffer (text), contents, len);
 }
 
-static void
-filesel_button_clicked (GtkWidget *w, glong *selected)
-{
-        *selected = (glong) g_object_get_data (G_OBJECT(w), "button");
-}
-
 /**
  * gnome_db_select_file_dialog
  */
@@ -715,45 +709,24 @@ gchar *
 gnome_db_select_file_dialog (GtkWidget *parent, const gchar *title)
 {
 	GtkWidget *filesel;
-        glong *selected;
         gchar *res = NULL;
 
-        selected = (glong *) g_malloc (sizeof (glong));
-        *selected = 0;
-
         /* create dialog */
         filesel = gtk_file_selection_new (title);
-        g_object_set_data (G_OBJECT (GTK_FILE_SELECTION (filesel)->ok_button),
-			   "button", (gpointer) 1);
-        g_signal_connect (G_OBJECT (GTK_FILE_SELECTION(filesel)->ok_button),
-                           "clicked", G_CALLBACK (filesel_button_clicked),
-                           (gpointer) selected);
-        g_object_set_data (G_OBJECT (GTK_FILE_SELECTION(filesel)->cancel_button),
-                            "button", (gpointer) 2);
-        g_signal_connect (G_OBJECT (GTK_FILE_SELECTION (filesel)->cancel_button),
-                           "clicked", G_CALLBACK (filesel_button_clicked),
-                           (gpointer) selected);
-
 	if (GTK_IS_WINDOW (parent)) {
 		gtk_window_set_transient_for (GTK_WINDOW (filesel),
 				              GTK_WINDOW (parent));
 	}
-        gtk_widget_show (filesel);
         gtk_file_selection_show_fileop_buttons (GTK_FILE_SELECTION (filesel));
 
         /* wait for selection from user */
-        while (!*selected)
-                gtk_main_iteration_do (TRUE);
-        if (*selected == 1) { /* OK button */
-                res = g_strdup (gtk_file_selection_get_filename (
-					GTK_FILE_SELECTION (filesel)));
-	}
+	if (gtk_dialog_run (GTK_DIALOG (filesel)) == GTK_RESPONSE_OK)
+		res = g_strdup (gtk_file_selection_get_filename (GTK_FILE_SELECTION (filesel)));
         else
 		res = NULL;
 
         /* clean up */
         gtk_widget_destroy (filesel);
-        g_free (selected);
 
         return res;
 }
