@@ -26,24 +26,27 @@
 #include <libgda/libgda.h>
 #include <libgnomedb/gnome-db-browser.h>
 #include <libgnomedb/gnome-db-combo.h>
+#include <libgnomedb/gnome-db-config.h>
+#include <libgnomedb/gnome-db-connection-properties.h>
 #include <libgnomedb/gnome-db-connection-selector.h>
 #include <libgnomedb/gnome-db-control.h>
 #include <libgnomedb/gnome-db-control-widget.h>
 #include <libgnomedb/gnome-db-data-source-selector.h>
 #include <libgnomedb/gnome-db-dsn-config-druid.h>
 #include <libgnomedb/gnome-db-dsn-config.h>
+#include <libgnomedb/gnome-db-editor.h>
 #include <libgnomedb/gnome-db-error.h>
 #include <libgnomedb/gnome-db-error-dialog.h>
 #include <libgnomedb/gnome-db-form.h>
 #include <libgnomedb/gnome-db-gray-bar.h>
 #include <libgnomedb/gnome-db-grid.h>
+#include <libgnomedb/gnome-db-icon-list.h>
 #include <libgnomedb/gnome-db-list.h>
 #include <libgnomedb/gnome-db-login.h>
 #include <libgnomedb/gnome-db-login-dialog.h>
 #include <libgnomedb/gnome-db-model.h>
 #include <libgnomedb/gnome-db-provider-selector.h>
 #include <libgnomedb/gnome-db-report-editor.h>
-#include <libgnomedb/gnome-db-sql-editor.h>
 #include <libgnomedb/gnome-db-stock.h>
 #include <libgnomedb/gnome-db-table-editor.h>
 #include <libgnomedb/gnome-db-util.h>
